@@ -1,6 +1,6 @@
 import datetime,random,time
 
-from common_pims.lib.public import *
+from commonpi.lib.public import *
 
 class Context:
     # pass
